/*
 *    SPDX-FileCopyrightText: 2025 Joshua Goins <josh@redstrate.com>
 *    SPDX-License-Identifier: LGPL-2.0-or-later
 */

#include "clipstudio.h"

#include <QFile>
#include <QIODevice>
#include <QImage>

#include "reader.h"

bool ClipStudioHandler::canRead() const
{
    if (canRead(device())) {
        setFormat("clip");
        return true;
    }
    return false;
}

bool ClipStudioHandler::read(QImage *image)
{
    const auto imageData = readThumbnail(device());
    if (imageData.isEmpty()) {
        return false;
    }

    image->loadFromData(imageData, "PNG");
    return true;
}

bool ClipStudioHandler::canRead(QIODevice *device)
{
    if (!device) {
        qWarning("ClipStudioHandler::canRead() called with no device");
        return false;
    }
    if (device->isSequential()) {
        return false;
    }

    if (device->peek(4) == QByteArray::fromRawData("\x43\x53\x46\x43", 4)) {
        return true;
    }

    return false;
}

QImageIOPlugin::Capabilities ClipStudioPlugin::capabilities(QIODevice *device, const QByteArray &format) const
{
    if (format == "clip") {
        return Capabilities(CanRead);
    }
    if (!format.isEmpty()) {
        return {};
    }
    if (!device->isOpen()) {
        return {};
    }

    Capabilities cap;
    if (device->isReadable() && ClipStudioHandler::canRead(device)) {
        cap |= CanRead;
    }
    return cap;
}

QImageIOHandler *ClipStudioPlugin::create(QIODevice *device, const QByteArray &format) const
{
    QImageIOHandler *handler = new ClipStudioHandler;
    handler->setDevice(device);
    handler->setFormat(format);
    return handler;
}

#include "moc_clipstudio.cpp"
