/*
 *    SPDX-FileCopyrightText: 2025 Joshua Goins <josh@redstrate.com>
 *    SPDX-License-Identifier: LGPL-2.0-or-later
 */

#include "reader.h"

#include <QSqlDatabase>
#include <QSqlQuery>
#include <QTemporaryFile>

QByteArray readThumbnail(QIODevice *device)
{
    QByteArray data = device->readAll();
    if (data.isEmpty()) {
        return {};
    }

    const auto dbIndex = data.indexOf("SQLite format 3");
    if (dbIndex == -1) {
        return {};
    }
    const auto dbSize = data.size() - dbIndex;
    if (dbSize <= 0) {
        return {};
    }

    QByteArray sqliteDb = data.right(dbSize);

    QTemporaryFile file;
    file.open();
    file.write(sqliteDb);
    file.close();

    auto database = QSqlDatabase::addDatabase(QStringLiteral("QSQLITE"));
    database.setDatabaseName(file.fileName());
    if (!database.open()) {
        return {};
    }

    QSqlQuery query(database);
    query.exec(QStringLiteral("SELECT ImageData FROM CanvasPreview"));
    query.next();
    return query.value(0).toByteArray();
}
