/*
 *    SPDX-FileCopyrightText: 2025 Joshua Goins <josh@redstrate.com>
 *    SPDX-License-Identifier: LGPL-2.0-or-later
 */

#include "clipstudiocreator.h"

#include <QFile>
#include <QImage>
#include <QPointer>
#include <QtEndian>

#include <KPluginFactory>

#include "reader.h"

K_PLUGIN_CLASS_WITH_JSON(ClipStudioCreator, "clipstudiothumbnail.json")

ClipStudioCreator::ClipStudioCreator(QObject *parent, const QVariantList &args)
    : KIO::ThumbnailCreator(parent, args)
{
}

KIO::ThumbnailResult ClipStudioCreator::create(const KIO::ThumbnailRequest &request)
{
    QFile file(request.url().toLocalFile());
    if (!file.open(QIODevice::ReadOnly)) {
        return KIO::ThumbnailResult::fail();
    }

    const auto imageData = readThumbnail(&file);
    if (imageData.isEmpty()) {
        return KIO::ThumbnailResult::fail();
    }

    QImage image;
    image.loadFromData(imageData, "PNG");

    return KIO::ThumbnailResult::pass(image);
}

#include "clipstudiocreator.moc"
